@@ -110,7 +110,8 @@ class Core:
         path: str,
         columns: list,
         types: dict,
-        parse_dates: list
+        parse_dates: list,
+        coerce_dates: bool = False
     ) -> pd.DataFrame:
 
         try:
@@ -123,6 +124,11 @@ class Core:
                 dtype=types,
                 parse_dates=parse_dates)
 
+            # Force datetime conversion
+            if coerce_dates:
+                df.iloc[:, parse_dates] = df.iloc[:, parse_dates].apply(
+                    pd.to_datetime, errors='coerce')
+
         except HTTPError:
 
             # Create empty DataFrane
