@@ -156,6 +156,11 @@ class Daily(Core):
             # Data Processing
             self._processing_handler(datasets, self._load, self.max_threads)
 
+        else:
+
+            # Empty DataFrame
+            self._data = pd.DataFrame(columns=[*self._types])
+
     def _resolve_point(
         self,
         method: str,
@@ -167,6 +172,9 @@ class Daily(Core):
         Project weather station data onto a single point
         """
 
+        if self._stations.size == 0:
+            return None
+
         if method == 'nearest':
 
             self._data = self._data.groupby(
@@ -226,9 +234,9 @@ class Daily(Core):
             self._stations = stations.index
         else:
             if not isinstance(loc, list):
-                stations = [loc]
+                loc = [loc]
 
-            self._stations = pd.Index(stations)
+            self._stations = pd.Index(loc)
 
         # Set start date
         self._start = start
